Structs
- Action
Channel - In-memory channel shared between a client and a server (same-process semantics).
- Basic
Action Client - Basic
Action Server
Traits
- Action
Client - Client-side handle: sends goals, polls feedback, and retrieves the final result.
- Action
Server - Server-side handle: receives goals, publishes feedback, and sends the final result.