pub enum ActionLiveness {
Active,
Stalled,
TimedOut,
Completed,
Unknown,
}Expand description
Liveness classification for an action goal session.
Variants
Active
The goal is progressing and heartbeat is within timeout budget.
Stalled
The goal is not timed out yet but heartbeat age exceeds the stalled threshold.
TimedOut
The goal exceeded heartbeat timeout budget.
Completed
Terminal goals are considered completed.
Unknown
Insufficient data to classify liveness.